@@ -1,19 +1,23 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from random import randint
+from random import choice
 from termcolor import colored
+from termcolor import COLORS
 
 class XmasTree(object):
 
-    def __init__(self, height=20, center=80, greeting="Merry Xmas!"):
+    def __init__(self, height=20, center=80, greeting="Merry Xmas!", ornament="!@#$%^&", blink=True):
         self.height = height
         self.center = center
         self.greeting = greeting
+        self.ornament = ornament
+        self.blink = blink
         self._new_tree()
 
     def _ornament(self):
         if randint(0, 99) > 80:
-            return "!@#$%^&"[randint(0, 6)]
+            return choice(self.ornament)
         else:
             return ' '
 
@@ -34,11 +38,18 @@ class XmasTree(object):
                           self._bough((self.height - 1) // 2, True) + ['| |'])
         self.tree = '\n'.join([s.center(self.center)
                                for s in self.boughs])
+        if self.blink:
+            for i in self.ornament:
+                self.tree = self.tree.replace(i, colored(i, choice(COLORS.keys()), attrs=['blink', 'bold']))
+                if randint(0, 99) > 50:
+                    self.tree = self.tree.replace(i, colored(choice(self.ornament), choice(COLORS.keys()), attrs=['blink', 'bold']))
+            self.tree = self.tree.replace('/', colored('/', 'green', attrs=['bold'])).replace('\\', colored('\\', 'green', attrs=['bold']))
+            self.tree = self.tree.replace('*', colored('*', 'green', attrs=['bold'])).replace('_', colored('_', 'green', attrs=['bold']))
 
     def show(self):
-        print colored(self.tree, 'green', attrs=['bold'])
-        print colored(self.greeting, 'red', attrs=['bold', 'blink', 'reverse', 'underline'])
-
+        print self.tree
+        print
+        print colored(self.greeting.center(self.center), 'red', attrs=['bold', 'underline'])
 
 def main():
     import argparse
@@ -58,8 +69,18 @@ def main():
                         type=str,
                         default='Merry Xmas!',
                         dest="greeting")
+    parser.add_argument("--ornament", '-O',
+                        help="ornaments",
+                        type=str,
+                        default='!@#$%^&',
+                        dest="ornament")
+    parser.add_argument("--no-blink", '-B',
+                        help="colorful blinking",
+                        default=True,
+                        action="store_false",
+                        dest="blink")
     args = parser.parse_args()
-    tree = XmasTree(args.height, args.center, args.greeting)
+    tree = XmasTree(args.height, args.center, args.greeting, args.ornament, args.blink)
     tree.show()
 
 if __name__ == '__main__':
